@@ -26,6 +26,16 @@ class AirWorksApi:
         self.default_page_size = kwargs.get("default_page_size", 100)
         self.default_debug = kwargs.get("debug", False)
 
+    def __del__(self):
+        try:
+            self.close()
+        except:
+            pass
+
+    def close(self):
+        self.base_api.close()
+        return
+
     def _call(self, api_url, **kwargs):
         app_id = kwargs.get("app_id", self.default_app_id)
         if not app_id:
